

#ifndef _PLAYLIST2_H_
#define _PLAYLIST2_H_

#include <qvaluelist.h>
#include <qstringlist.h>
#include <qmainwindow.h>

class PlaylistItem {

public:
	PlaylistItem() { _filename=""; _name=""; _duration=0; 
                     _played = FALSE; _deleted=FALSE; };
	PlaylistItem(QString filename, QString name, double duration) {
		         _filename = filename; _name = name; _duration = duration; 
                 _played = FALSE; _deleted = FALSE; };
	~PlaylistItem() {};

	void setFilename(QString filename) { _filename = filename; };
	void setName(QString name) { _name = name; };
	void setDuration(double duration) { _duration = duration; };
	void setPlayed(bool b) { _played = b; };
	void setMarkForDeletion(bool b) { _deleted = b; };

	QString filename() { return _filename; };
	QString name() { return _name; };
	double duration() { return _duration; };
	bool played() { return _played; };
	bool markedForDeletion() { return _deleted; };

private:
	QString _filename, _name;
	double _duration;
	bool _played, _deleted;
};


class QTable;
class QToolBar;
class MyAction;
class Core;
class QPopupMenu;
class QSettings;
class QToolButton;

class Playlist : public QMainWindow
{
	Q_OBJECT

public:
	Playlist( Core *c, QWidget * parent = 0, const char * name = 0, WFlags f = WType_TopLevel );
	~Playlist();

public slots:
	void clear();
	void list();
	int count();
	bool isEmpty();

	void addItem(QString filename, QString name, double duration);

	// Start playing, from item 0 if shuffle is off, or from
	// a random item otherwise
	void startPlay();

	void playItem(int n);

	virtual void playNext();
	virtual void playPrev();

	virtual void removeSelected();
	virtual void removeAll();

	virtual void addCurrentFile();
	virtual void addFiles();
	virtual void addDirectory();

	virtual void addFiles(QStringList files);
	virtual void addDirectory(QString dir);

    virtual void load();
    virtual void save();

	virtual void load_m3u(QString file);
	virtual void save_m3u(QString file);

	virtual void getMediaInfo();

	virtual void saveSettings();
	virtual void loadSettings();

public:
	MyAction * playPrevAct() { return prevAct; };
	MyAction * playNextAct() { return nextAct; };

signals:
	void playlistEnded();
	void visibilityChanged();

protected:
	void updateView();
	void setCurrentItem(int current);
	void clearPlayedTag();
	int chooseRandomItem();
	void swapItems(int item1, int item2 );
	QString lastDir();

	virtual void dragEnterEvent( QDragEnterEvent * ) ;
	virtual void dropEvent ( QDropEvent * );
	virtual void hideEvent ( QHideEvent * );
	virtual void showEvent ( QShowEvent * );
	virtual void closeEvent( QCloseEvent * e );

protected slots:
	virtual void languageChange();

	virtual void playCurrent();
	virtual void itemDoubleClicked(int row);
	virtual void showPopup(int row, int col, const QPoint & pos);
	virtual void upItem();
	virtual void downItem();
	virtual void editCurrentItem();
	virtual void editItem(int item);

protected:
	void createTable();
	void createActions();
	void createToolbar();

protected:
	typedef QValueList <PlaylistItem> PlaylistItemList;
	PlaylistItemList pl;
	int current_item;

	QString playlist_path;
	QString latest_dir;

	Core * core;
	QPopupMenu * add_menu;
	QPopupMenu * remove_menu;
	QPopupMenu * popup;

	QTable * listView;

	QToolBar * toolbar;
	QToolButton * add_button;
	QToolButton * remove_button;

	MyAction * openAct;
	MyAction * saveAct;
	MyAction * playAct;
	MyAction * prevAct;
	MyAction * nextAct;
	MyAction * repeatAct;
	MyAction * shuffleAct;
	MyAction * moveUpAct;
	MyAction * moveDownAct;
	MyAction * editAct;

	MyAction * addCurrentAct;
	MyAction * addFilesAct;
	MyAction * addDirectoryAct;

	MyAction * removeSelectedAct;
	MyAction * removeAllAct;
};


#endif

